#!/usr/bin/env python3

from databroker import catalog
from databroker.queries import TimeRange
import pandas as pd
from datetime import datetime

import databroker.tutorial_utils

from bluesky import RunEngine
from ophyd.sim import det, motor, SynSignal, det4, motor1, motor2
from bluesky.plans import count, scan, grid_scan

from bluesky_widgets.utils.streaming import stream_documents_into_runs
from bluesky_widgets.models.plot_builders import Lines
# from bluesky_widgets.qt.figures import QtFigure

import tempfile
from suitcase.msgpack import Serializer
import tableprint as tp
import numpy as np

from datetime import datetime
import argparse

from databroker._drivers.msgpack import BlueskyMsgpackCatalog


class ls():
    """This class holds the act of going from the searching the catalog to a pandas dataframe"""


    catalog = catalog['bluesky-tutorial-BMM'] # particular catalog we're referencing
    removableCatalog = [] # the catalog's list of UUIDs will be copied in here, and then removed as they are printed
    TIME = '' # this is a parameter I may want to change later
    CHUNK_SIZE = 100 # how many entries get loaded in each group

    def __init__(self):
        """
            The goal is to load all UUIDs into the removableCatalog variable
            This way, the user can load as many or as few entries as they choose
            PROBLEM: These are unordered
        """

        super().__init__()
        query = TimeRange() # when no time range is specified, it loads all entries
        self.removableCatalog = list(self.catalog.search(query)) # how all the UUIDs are loaded into removable catalog
        UUIDtoTime = {self.removableCatalog[x]: self.catalog[self.removableCatalog[x]].metadata["start"]["time"] for x in range(len(self.removableCatalog))}
        self.removableCatalog = list(x[0] for x in sorted(UUIDtoTime.items(), key=lambda x: x[1]))

    def getCurrentSubcatalog(self, chunk_size):
        """"
            Helper function for toPandas() method
            This gets the next section of the catalog to display
            Removes the UUIDS used from removableCatalog
        """

        currentView = self.removableCatalog[:chunk_size] #puts the UUIDs we are looking at in a smaller list
        del self.removableCatalog[:chunk_size] # removes same UUIDs from removableCatalog
        return currentView

    def toReadableDate(self, linuxtime):
        """Linux time to human readable date and time"""
        return datetime.utcfromtimestamp(linuxtime).strftime('%Y-%m-%d %H:%M:%S')

    def toPandas(self):
        """
        Takes the UUIDs and puts them into actual bluesky runs
        Takes these runs to get info that we can list for users, to make runs easier to find
        """

        # currentView = self.getCurrentSubcatalog(self.CHUNK_SIZE) # get what we want to load so far
        # #next line: actual information we want to format (get info from bluesky runs)
        # data = [[self.toReadableDate(self.catalog[x].metadata["start"]["time"]), self.catalog[x].metadata["start"]["scan_id"], (self.catalog[x].metadata["start"]["uid"])[:8]] for x in currentView]
        #
        # indexing = pd.Series([x for x in range(-1, (len(currentView) + 1) * -1, -1)]) # default pandas indexing is misleading --> turn into something databroker actuall uses (backward index)
        #
        # df = pd.DataFrame(data, columns =['Start Time', 'Scan ID', 'UUID Partial']).set_index(indexing) # label the columns and set the indexes to indexing made in prev line
        # df.index.name = 'Backwards Index' # give index column a name
        return self.myOwnPrinting()
        #return df

    def toTablePrint(self):
        currentView = self.getCurrentSubcatalog(self.CHUNK_SIZE)  # get what we want to load so far
        # next line: actual information we want to format (get info from bluesky runs)
        data = np.array([[self.toReadableDate(self.catalog[x].metadata["start"]["time"]),
                 self.catalog[x].metadata["start"]["scan_id"], (self.catalog[x].metadata["start"]["uid"])[:8]] for x in
                currentView])
        tp.banner("Welcome to tableprint!")
        tp.table(data, ['Start Time', 'Scan ID', 'Partial UUID'])

    def myOwnPrinting(self):
        currentView = self.getCurrentSubcatalog(self.CHUNK_SIZE)  # get what we want to load so far
        data = [[self.toReadableDate(self.catalog[x].metadata["start"]["time"]),
                 self.catalog[x].metadata["start"]["scan_id"], (self.catalog[x].metadata["start"]["uid"])[:8]]
                for x in currentView]
        if len(data) != 0:
            for arr in data:
                print(arr[0], "   ", arr[1], "   ", arr[2])
            return "Hit enter to see more"
        else:
            return "exit"


#--------------------------------------------------
def main():
    """Make a jazz noise here"""
    object = ls() # instantiates object


# --------------------------------------------------
if __name__ == '__main__':
    main()




from pynput import keyboard
from pynput.keyboard import Key, Controller

from databroker_ls.qt import ls

"""
This file is a script to actually make the lines load dynamically
"""

def on_press(key, object):
    """
    Handle key presses: we only care about escape and enter
    """
    if key == keyboard.Key.esc:
        # Stop listener and get out of the loading window, back to regular terminal
        return False
    else:
        if key == keyboard.Key.enter:
            # load the next iteration of the catalog
            print(object.myOwnPrinting())
            # if (object.myOwnPrinting() == "exit"):
            #     return False

def main():
    object = ls() # instantiate new ls object
    print("Starting Time          Scan ID      UUID")
    print(object.myOwnPrinting()) # start by loading the first set of entries
    # Collect events until released
    with keyboard.Listener(on_press=lambda event: on_press(event, object=object)) as listener:
        listener.join() # will only join back up with the terminal when we return False


if __name__ == '__main__':
    main()


import databroker.tutorial_utils

databroker.tutorial_utils.fetch_RSOXS_example()

import databroker

from bluesky import RunEngine
from ophyd.sim import det, motor, SynSignal, det4, motor1, motor2
from bluesky.plans import count, scan, grid_scan

from bluesky_widgets.utils.streaming import stream_documents_into_runs
from bluesky_widgets.models.plot_builders import Lines
from bluesky_widgets.qt.figures import QtFigure

import tempfile
from suitcase.msgpack import Serializer
import numpy as np

from databroker._drivers.msgpack import BlueskyMsgpackCatalog

databroker.tutorial_utils.fetch_BMM_example()
catalog = databroker.catalog['bluesky-tutorial-BMM']

import pandas as pd
from datetime import datetime

def toReadableDate(linuxtime):
  return datetime.utcfromtimestamp(linuxtime).strftime('%Y-%m-%d %H:%M:%S')

def ls():
  data = [[toReadableDate(catalog[x].metadata["start"]["time"]), catalog[x].metadata["start"]["scan_id"], catalog[x].metadata["start"]["uid"],] for x in catalog]

  indexing = pd.Series([x for x in range(-1, (len(catalog) + 1) * -1, -1)])

  df = pd.DataFrame(data, columns =['Start Time', 'Scan ID', 'UUID']).set_index(indexing)
  df.index.name = 'Backwards Index'
  return df

print(ls())


#!/usr/bin/env python3
"""tests for hello.py"""

import os
from subprocess import getstatusoutput, getoutput

prg = '/Users/claracook/Desktop/test/databroker-ls/databroker_ls/stupid-ls.py'


# --------------------------------------------------
def test_exists():
    """exists"""

    assert os.path.isfile(prg)


# --------------------------------------------------
def test_runnable():
    """Runs using python3"""

    out = getoutput(f'python3 {prg}')
    assert out.strip() != 'Hello, World!'




import time
import curses
import os

from time import sleep
from sys import stdout

for i in range(1,20):
    stdout.write("\r%d" % i)
    stdout.flush()
    sleep(1)
stdout.write("\n") # move the cursor to the next line

# width, height = os.get_terminal_size()
#
# N=12
#
# for i in range(N):
#    sleep(0.5)
#    print(f"{i/N*100:.1f} %", end="\r")

# def pbar():
#     reallyLongStr = "Mr. and Mrs. Dursley, of number four, Privet Drive, were proud to say that they were perfectly normal, thank you very much. They were the last people you'd expect to be involved in anything strange or mysterious, because they just didn't hold with such nonsense. Mr. Dursley was the director of a firm called Grunnings, which made drills. He was a big, beefy man with hardly any neck, although he did have a very large mustache. Mrs. Dursley was thin and blonde and had nearly twice the usual amount of neck, which came in very useful as she spent so much of her time craning over garden fences, spying on the neighbors. The Dursleys had a small son called Dudley and in their opinion there was no finer boy anywhere. The Dursleys had everything they wanted, but they also had a secret, and their greatest fear was that somebody would discover it. They didn't think they could bear it if anyone found out about the Potters. Mrs. Potter was Mrs. Dursley's sister, but they hadn't met for several years; in fact, Mrs. Dursley pretended she didn't have a sister, because her sister and her good-for-nothing husband were as unDursleyish as it was possible to be. The Dursleys shuddered to think what the neighbors would say if the Potters arrived in the street. The Dursleys knew that the Potters had a small son, too, but they had never even seen him. This boy was another good reason for keeping the Potters away; they didn't want Dudley mixing with a child like that."
#     reallyLongStr = reallyLongStr.replace(" ", "\n")
#     print(reallyLongStr, end='\r')
#
# pbar()
